Revision
--------

.. autosimple:: swh.web.api.views.revision.api_revision

.. autosimple:: swh.web.api.views.revision.api_revision_directory

.. autosimple:: swh.web.api.views.revision.api_revision_log

